summaryrefslogtreecommitdiffstats
path: root/shared
diff options
context:
space:
mode:
authorLeif Åstrand <leif@vaadin.com>2012-11-16 16:42:21 +0200
committerLeif Åstrand <leif@vaadin.com>2012-11-16 16:43:05 +0200
commit15f833480da7a5eff0d29c527cd956b9e9658401 (patch)
treef6fdb7013fa3fab366c892a45edee84441773c03 /shared
parente54ff59fbe6a5452b469a355176351cd710663d1 (diff)
downloadvaadin-framework-15f833480da7a5eff0d29c527cd956b9e9658401.tar.gz
vaadin-framework-15f833480da7a5eff0d29c527cd956b9e9658401.zip
@Connect lastonly -> lastOnly (#10244)
Change-Id: I5d587852d00b485eb57e10ad3ba874ea1b500a19
Diffstat (limited to 'shared')
-rw-r--r--shared/src/com/vaadin/shared/annotations/Delayed.java4
-rw-r--r--shared/src/com/vaadin/shared/communication/LegacyChangeVariablesInvocation.java4
-rw-r--r--shared/src/com/vaadin/shared/communication/MethodInvocation.java6
-rw-r--r--shared/src/com/vaadin/shared/ui/ui/UIServerRpc.java2
4 files changed, 8 insertions, 8 deletions
diff --git a/shared/src/com/vaadin/shared/communication/LegacyChangeVariablesInvocation.java b/shared/src/com/vaadin/shared/communication/LegacyChangeVariablesInvocation.java
index 2ffc56dd71..c41087e284 100644
--- a/shared/src/com/vaadin/shared/communication/LegacyChangeVariablesInvocation.java
+++ b/shared/src/com/vaadin/shared/communication/LegacyChangeVariablesInvocation.java
@@ -48,9 +48,9 @@ public class LegacyChangeVariablesInvocation extends MethodInvocation {
}
@Override
- public String getLastonlyTag() {
+ public String getLastOnlyTag() {
assert variableChanges.size() == 1;
- return super.getLastonlyTag()
+ return super.getLastOnlyTag()
+ variableChanges.keySet().iterator().next();
}
diff --git a/shared/src/com/vaadin/shared/ui/ui/UIServerRpc.java b/shared/src/com/vaadin/shared/ui/ui/UIServerRpc.java
index ef28a12415..11a400bbe0 100644
--- a/shared/src/com/vaadin/shared/ui/ui/UIServerRpc.java
+++ b/shared/src/com/vaadin/shared/ui/ui/UIServerRpc.java
@@ -20,7 +20,7 @@ import com.vaadin.shared.communication.ServerRpc;
import com.vaadin.shared.ui.ClickRpc;
public interface UIServerRpc extends ClickRpc, ServerRpc {
- @Delayed(lastonly = true)
+ @Delayed(lastOnly = true)
public void resize(int viewWidth, int viewHeight, int windowWidth,
int windowHeight);
} \ No newline at end of file
diff --git a/shared/src/com/vaadin/shared/annotations/Delayed.java b/shared/src/com/vaadin/shared/annotations/Delayed.java
index 706ffc1c53..a9914ac35f 100644
--- a/shared/src/com/vaadin/shared/annotations/Delayed.java
+++ b/shared/src/com/vaadin/shared/annotations/Delayed.java
@@ -37,7 +37,7 @@ import com.vaadin.shared.communication.ServerRpc;
@Documented
public @interface Delayed {
/**
* By setting lastonly to <code>true</code>, any previous invocations of the
* same method will be removed from the queue when a new invocation is
* added. This can be used in cases where only the last value is of
* interest.
@@ -50,5 +50,5 @@ public @interface Delayed {
* method should be sent to the server, <code>false</code> if all
* enqueued invocations should be sent.
*/
- public boolean lastonly() default false;
+ public boolean lastOnly() default false;
}
@@ -37,7 +37,7 @@ import com.vaadin.shared.communication.ServerRpc;
public @interface Delayed {
/**
- * By setting lastonly to <code>true</code>, any previous invocations of the
+ * By setting lastOnly to <code>true</code>, any previous invocations of the
* same method will be removed from the queue when a new invocation is
* added. This can be used in cases where only the last value is of
diff --git a/shared/src/com/vaadin/shared/communication/MethodInvocation.java b/shared/src/com/vaadin/shared/communication/MethodInvocation.java
index c4da937c27..1e683ce231 100644
--- a/shared/src/com/vaadin/shared/communication/MethodInvocation.java
+++ b/shared/src/com/vaadin/shared/communication/MethodInvocation.java
@@ -74,14 +74,14 @@ public class MethodInvocation implements Serializable {
/**
* Gets a String tag that is used to uniquely identify previous method
* invocations that should be purged from the queue if
- * <code>{@literal @}Delay(lastonly = true)</code> is used.
+ * <code>{@literal @}Delay(lastOnly = true)</code> is used.
* <p>
* The returned string should contain at least one non-number char to ensure
* it doesn't collide with the keys used for invocations without lastonly.
*
* @return a string identifying this method invocation
*/
- public String getLastonlyTag() {
+ public String getLastOnlyTag() {
return connectorId + "-" + getInterfaceName() + "-" + getMethodName();
}
@@ -74,14 +74,14 @@ public class MethodInvocation implements Serializable {
* <p>
* The returned string should contain at least one non-number char to ensure
- * it doesn't collide with the keys used for invocations without lastonly.
+ * it doesn't collide with the keys used for invocations without lastOnly.
*
* @return a string identifying this method invocation